bayespy.inference.vmp.nodes.multinomial.MultinomialMoments.compute_dims_from_values
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialMoments.compute_dims_from_values